@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Date         : 2020-12-30
 # @Author       : AaronJny
-# @LastEditTime : 2021-03-11
+# @LastEditTime : 2021-03-13
 # @FilePath     : /LuWu/luwu/core/models/classifier/__init__.py
 # @Desc         :
 import os
@@ -15,6 +15,7 @@ from luwu.core.preprocess.image.load import (
     write_tfrecords_to_target_path,
 )
 from luwu.utils import file_util
+import numpy as np
 
 
 class LuwuImageClassifier:
@@ -27,6 +28,7 @@ class LuwuImageClassifier:
         batch_size: int = 32,
         epochs: int = 30,
         project_id: int = 0,
+        image_size: int = 224,
         **kwargs,
     ):
         """
@@ -44,6 +46,7 @@ class LuwuImageClassifier:
         origin_dataset_path = file_util.abspath(origin_dataset_path)
         target_dataset_path = file_util.abspath(target_dataset_path)
         model_save_path = file_util.abspath(model_save_path)
+        self.image_size = image_size
         self.origin_dataset_path = origin_dataset_path
         # 当未给定处理后数据集的路径时，默认保存到原始数据集相同路径
         if target_dataset_path:
@@ -67,6 +70,8 @@ class LuwuImageClassifier:
         self.validation_split = validation_split
         self.batch_size = batch_size
         self.epochs = epochs
+        file_util.mkdirs(self.project_save_path)
+        file_util.mkdirs(self.target_dataset_path)
 
     def build_model(self) -> tf.keras.Model:
         """构建模型
@@ -108,7 +113,10 @@ class LuwuImageClassifier:
         dev_nums = int(total * self.validation_split)
         dev_data = random.sample(data, dev_nums)
         train_data = list(set(data) - set(dev_data))
+        np.random.shuffle(train_data)
+        np.random.shuffle(dev_data)
         del data
+
         # 制作tfrecord数据集
         write_tfrecords_to_target_path(
             train_data, len(classes_num_dict), self.target_train_dataset_path
@@ -173,6 +181,7 @@ class LuwuImageClassifier:
 
 
 from luwu.core.models.classifier.preset import (
+    LuwuLeNetImageClassifier,
     LuwuDenseNet121ImageClassifier,
     LuwuDenseNet169ImageClassifier,
     LuwuDenseNet201ImageClassifier,
@@ -206,6 +215,7 @@ from luwu.core.models.classifier.preset import (
 __all__ = [
     "LuwuImageClassifier",
     "LuwuPreTrainedImageClassifier",
+    "LuwuLeNetImageClassifier",
     "LuwuDenseNet121ImageClassifier",
     "LuwuDenseNet169ImageClassifier",
     "LuwuDenseNet201ImageClassifier",
